@@ -1,24 +1,9 @@
-#
-# This file is part of Pod-Weaver-Section-Support
-#
-# This software is copyright (c) 2011 by Apocalypse.
-#
-# This is free software; you can redistribute it and/or modify it under
-# the same terms as the Perl 5 programming language system itself.
-#
-use strict; use warnings;
 package Pod::Weaver::Section::Support;
-BEGIN {
-  $Pod::Weaver::Section::Support::VERSION = '1.004';
-}
-BEGIN {
-  $Pod::Weaver::Section::Support::AUTHORITY = 'cpan:APOCAL';
-}
-
+$Pod::Weaver::Section::Support::VERSION = '1.009';
 # ABSTRACT: Add a SUPPORT section to your POD
 
 use Moose 1.03;
-use Moose::Autobox 0.10;
+use PPIx::DocumentName;
 
 with 'Pod::Weaver::Role::Section' => { -version => '3.100710' };
 
@@ -165,36 +150,34 @@ sub weave_section {
 		return if $zilla->main_module->name ne $input->{filename};
 	}
 
-	$document->children->push(
-		# Add the stopwords so the spell checker won't complain!
-		# TODO make this smarter so it loads only the stopwords we need for specific sections... ohwell
-		Pod::Elemental::Element::Pod5::Region->new( {
+	# Add the stopwords so the spell checker won't complain!
+	# TODO make this smarter so it loads only the stopwords we need for specific sections... ohwell
+	push @{ $document->children }, Pod::Elemental::Element::Pod5::Region->new( {
 			format_name => 'stopwords',
 			is_pod => 1,
 			content => '',
 			children => [
 				Pod::Elemental::Element::Pod5::Ordinary->new( {
-					content => join( " ", qw( cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders ) ),
+					content => join( " ", qw( cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan ) ),
 				} ),
 			],
-		} ),
-		Pod::Elemental::Element::Nested->new( {
+	} ),
+	Pod::Elemental::Element::Nested->new( {
 			command => 'head1',
 			content => 'SUPPORT',
 			children => [
-				$self->_add_perldoc( $zilla ),
+				$self->_add_perldoc( $input->{ppi_document} ),
 				$self->_add_websites( $zilla ),
 				$self->_add_email( $zilla ),
 				$self->_add_irc( $zilla ),
 				$self->_add_bugs( $zilla, $input->{'distmeta'} ),
 				$self->_add_repo( $zilla ),
 			],
-		} ),
-	);
+	} );
 }
 
 sub _add_email {
-	my( $self, $zilla ) = @_;
+	my $self = shift;
 
 	# Do we have anything to do?
 	return () if ! defined $self->email;
@@ -232,26 +215,26 @@ sub _add_bugs {
 	if ( $self->bugs eq 'rt' ) {
 		my $dist = $zilla->name;
 		my $mailto = "C<bug-" . lc( $dist ) . " at rt.cpan.org>";
-		my $web = "L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=$dist>";
+		my $web = "L<https://rt.cpan.org/Public/Bug/Report.html?Queue=$dist>";
 
 		$text =~ s/\{WEB\}/$web/;
 		$text =~ s/\{EMAIL\}/$mailto/;
 	} else {
 		# code copied from Pod::Weaver::Section::Bugs, thanks RJBS!
-		$zilla->log_fatal( 'No bugtracker in metadata!' ) unless exists $distmeta->{resources}{bugtracker};
+		$self->log_fatal( 'No bugtracker in metadata!' ) unless exists $distmeta->{resources}{bugtracker};
 		my $bugtracker = $distmeta->{resources}{bugtracker};
 		my( $web, $mailto ) = @{$bugtracker}{qw/web mailto/};
-		$zilla->log_fatal( 'No bugtracker in metadata!' ) unless defined $web || defined $mailto;
+		$self->log_fatal( 'No bugtracker in metadata!' ) unless defined $web || defined $mailto;
 
 		$text =~ s/\{WEB\}/L\<$web\>/ if defined $web;
 		$text =~ s/\{EMAIL\}/C\<$mailto\>/ if defined $mailto;
 
 		# sanity check the content
 		if ( $text =~ /\{WEB\}/ ) {
-			$zilla->log_fatal( "The metadata doesn't have a website for the bugtracker but you specified it in the bugs_content!" );
+			$self->log_fatal( "The metadata doesn't have a website for the bugtracker but you specified it in the bugs_content!" );
 		}
 		if ( $text =~ /\{EMAIL\}/ ) {
-			$zilla->log_fatal( "The metadata doesn't have an email for the bugtracker but you specified it in the bugs_content!" );
+			$self->log_fatal( "The metadata doesn't have an email for the bugtracker but you specified it in the bugs_content!" );
 		}
 	}
 
@@ -267,17 +250,13 @@ sub _add_bugs {
 }
 
 sub _add_perldoc {
-	my( $self, $zilla ) = @_;
+	my( $self, $ppi_doc ) = @_;
 
 	# Do we have anything to do?
 	return () if ! $self->perldoc;
 
-	# Don't use $zilla->name as some dists' name is different from the actual module...
-	# TODO what if user specified $self->all_modules( 1 )? should this use the current filename?
-	my $main_module = $zilla->main_module->name;
-	$main_module =~ s|^lib/||i;
-	$main_module =~ s/\.pm$//;
-	$main_module =~ s|/|::|g;
+	# Get the name for the module
+	my $module = PPIx::DocumentName->extract( $ppi_doc );
 
 	# TODO add language detection as per RT#63726
 
@@ -292,36 +271,60 @@ EOPOD
 
 			} ),
 			Pod::Elemental::Element::Pod5::Verbatim->new( {
-				content => "  perldoc $main_module",
+				content => "  perldoc $module",
 			} ),
 		],
 	} );
 }
 
 sub _add_irc {
-	my( $self, $zilla ) = @_;
+	my $self = shift;
+	my $zilla = shift;
 
-	# Do we have anything to do?
-	return () if ! scalar @{ $self->irc };
+	my @irc;
+
+	# thanks to https://metacpan.org/about/metadata for the info!
+	if ( scalar @{ $self->irc } ) {
+		$self->log( 'IRC was set twice: in the metadata and in this plugin, overriding the metadata!' ) if exists $zilla->distmeta->{'x_IRC'};
+		@irc = @{ $self->irc };
+	} elsif ( exists $zilla->distmeta->{'x_IRC'} ) {
+		my $x_irc = $zilla->distmeta->{'x_IRC'};
+		if ( ref $x_irc ) { # handle the newer url/web nested spec
+			$x_irc = $x_irc->{'url'};
+		}
+		if ( $x_irc =~ m|^irc://([^/]+)/(.+)$| ) {
+			push( @irc, "$1,$2" );
+		} else {
+			$self->log( "Error: the IRC metadata needs to be in the proper format: 'irc://servername.com/#room' but yours was: $x_irc" );
+			return ();
+		}
+	} else {
+		return ();
+	}
 
 	my @networks;
-	foreach my $entry ( @{ $self->irc } ) {
-		# Split it into fields
-		my @data = split( /\,/, $entry );
-		$_ =~ s/^\s+//g for @data;
-		$_ =~ s/\s+$//g for @data;
+	foreach my $entry ( @irc ) {
+		my( $net, @chans, @nicks );
+		if ( $entry =~ m|^irc://([^/]+)/(.+)$| ) {
+			$net = $1;
+			push( @chans, $2 );
+		} else {
+			# Split it into fields
+			my @data = split( /\,/, $entry );
+			$_ =~ s/^\s+//g for @data;
+			$_ =~ s/\s+$//g for @data;
 
-		# Add the network data!
-		my $net = shift @data;
-		my @chans;
-		my @nicks;
-		foreach my $e ( @data ) {
-			if ( $e =~ /^\#/ ) {
-				push( @chans, $e );
-			} else {
-				push( @nicks, $e );
+			# Add the network data!
+			$net = shift @data;
+			foreach my $e ( @data ) {
+				if ( $e =~ /^\#/ ) {
+					push( @chans, $e );
+				} else {
+					push( @nicks, $e );
+				}
 			}
 		}
+
 		my $text = "You can connect to the server at '$net'";
 		if ( @chans ) {
 			if ( @chans > 1 ) {
@@ -385,7 +388,10 @@ sub _add_repo {
 	if ( exists $zilla->distmeta->{resources}{repository} ) {
 		$repo = $zilla->distmeta->{resources}{repository};
 	} else {
-		$zilla->log_fatal( [ "Repository information missing and you wanted: %s", $self->repository_link ] );
+		$self->log_fatal( [
+			"Repository information in meta.resources.repository is missing and you wanted: %s",
+			$self->repository_link eq 'both' ? 'both (web and url)' : $self->repository_link,
+		] );
 	}
 
 	my $text = join( "\n", @{ $self->repository_content } );
@@ -398,13 +404,13 @@ sub _add_repo {
 			if ( exists $repo->{web} ) {
 				$text .= 'L<' . $repo->{web} . ">";
 			} else {
-				$zilla->log_fatal("Expected to find 'web' repository link but it is missing in the metadata!");
+				$self->log_fatal("Expected to find 'web' repository link but it is missing in the metadata!");
 			}
 		}
 
 		if ( $self->repository_link eq 'url' or $self->repository_link eq 'both' ) {
 			if ( ! exists $repo->{url} ) {
-				$zilla->log_fatal("Expected to find 'url' repository link but it is missing in the metadata!");
+				$self->log_fatal("Expected to find 'url' repository link but it is missing in the metadata!");
 			}
 
 			if ( $self->repository_link eq 'both' ) {
@@ -433,7 +439,7 @@ sub _add_repo {
 			}
 		}
 	} else {
-		$zilla->log_warning("You need to update Dist::Zilla::Plugin::Repository to at least v0.15 for the correct metadata!");
+		$self->log_warning("You need to update Dist::Zilla::Plugin::Repository to at least v0.15 for the correct metadata!");
 		$text .= "L<$repo>";
 	}
 
@@ -473,14 +479,14 @@ sub _add_websites {
 
 	# sanity check
 	foreach my $type ( @{ $self->websites } ) {
-		if ( $type !~ /^(?:search|rt|anno|ratings|forum|kwalitee|testers|testmatrix|deps|all)$/i ) {
-			$zilla->log_fatal( "Unknown website type: $type" );
+		if ( $type !~ /^(?:metacpan|search|rt|anno|ratings|kwalitee|testers|testmatrix|deps|all)$/i ) {
+			$self->log_fatal( "Unknown website type: $type" );
 		}
 	}
 
 	# Set the default ordering for "all"
 	if ( grep { $_ eq 'all' } @{ $self->websites } ) { ## no critic ( BuiltinFunctions::ProhibitBooleanGrep )
-		@{ $self->websites } = qw( search rt anno ratings forum kwalitee testers testmatrix deps );
+		@{ $self->websites } = qw( metacpan search rt anno ratings kwalitee testers testmatrix deps );
 	}
 
 	# Make the website links!
@@ -493,7 +499,10 @@ sub _add_websites {
 		$main_module =~ s|^lib/||i;
 		$main_module =~ s/\.pm$//;
 		$main_module =~ s|/|::|g;
-		push( @links, $self->$type( $zilla->name, $main_module ) );
+
+		# TODO I'm too lazy to build a proper dispatch table...
+		no strict 'refs';
+		push( @links, &$type( $zilla->name, $main_module ) );
 	}
 
 	return Pod::Elemental::Element::Nested->new( {
@@ -518,8 +527,18 @@ sub _add_websites {
 	} );
 }
 
+sub _add_websites_metacpan {
+	my $dist = shift;
+
+	return _make_item( 'MetaCPAN', <<"EOF" );
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/$dist>
+EOF
+}
+
 sub _add_websites_search {
-	my( $self, $dist, $module ) = @_;
+	my $dist = shift;
 
 	return _make_item( 'Search CPAN', <<"EOF" );
 The default CPAN search engine, useful to view POD in HTML format.
@@ -529,27 +548,27 @@ EOF
 }
 
 sub _add_websites_rt {
-	my( $self, $dist, $module ) = @_;
+	my $dist = shift;
 
 	return _make_item( "RT: CPAN's Bug Tracker", <<"EOF" );
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=$dist>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=$dist>
 EOF
 }
 
 sub _add_websites_anno {
-	my( $self, $dist, $module ) = @_;
+	my $dist = shift;
 
 	return _make_item( 'AnnoCPAN', <<"EOF" );
-The AnnoCPAN is a website that allows community annonations of Perl module documentation.
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
 
 L<http://annocpan.org/dist/$dist>
 EOF
 }
 
 sub _add_websites_ratings {
-	my( $self, $dist, $module ) = @_;
+	my $dist = shift;
 
 	return _make_item( 'CPAN Ratings', <<"EOF" );
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
@@ -558,51 +577,40 @@ L<http://cpanratings.perl.org/d/$dist>
 EOF
 }
 
-sub _add_websites_forum {
-	my( $self, $dist, $module ) = @_;
-
-	return _make_item( 'CPAN Forum', <<"EOF" );
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/$dist>
-EOF
-}
-
 sub _add_websites_kwalitee {
-	my( $self, $dist, $module ) = @_;
+	my $dist = shift;
 
-	# TODO add link for http://perl-qa.hexten.net/wiki/index.php/Kwalitee ?
 	return _make_item( 'CPANTS', <<"EOF" );
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/$dist>
+L<http://cpants.cpanauthors.org/dist/$dist>
 EOF
 }
 
 sub _add_websites_testers {
-	my( $self, $dist, $module ) = @_;
+	my $dist = shift;
 
 	my $first_char = substr( $dist, 0, 1 );
 
 	return _make_item( 'CPAN Testers', <<"EOF" );
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/$first_char/$dist>
 EOF
 }
 
 sub _add_websites_testmatrix {
-	my( $self, $dist, $module ) = @_;
+	my $dist = shift;
 
 	return _make_item( 'CPAN Testers Matrix', <<"EOF" );
-The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
 
 L<http://matrix.cpantesters.org/?dist=$dist>
 EOF
 }
 
 sub _add_websites_deps {
-	my( $self, $dist, $module ) = @_;
+	my $module = $_[1];
 
 	return _make_item( 'CPAN Testers Dependencies', <<"EOF" );
 The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
@@ -632,16 +640,11 @@ sub _make_item {
 
 1;
 
-
 __END__
+
 =pod
 
-=for :stopwords Apocalypse cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee
-diff irc mailto metadata placeholders dist dzil repo
-
-=encoding utf-8
-
-=for Pod::Coverage weave_section mvp_multivalue_args
+=encoding UTF-8
 
 =head1 NAME
 
@@ -649,7 +652,7 @@ Pod::Weaver::Section::Support - Add a SUPPORT section to your POD
 
 =head1 VERSION
 
-  This document describes v1.004 of Pod::Weaver::Section::Support - released April 21, 2011 as part of Pod-Weaver-Section-Support.
+version 1.009
 
 =head1 DESCRIPTION
 
@@ -706,17 +709,17 @@ Specify what website links you want to see. This is an array, and you can pick a
 specify it as a comma-delimited string. The ordering of the options are important, as they are reflected in
 the final POD.
 
-Valid options are: "none", "search", "rt", "anno", "ratings", "forum", "kwalitee", "testers", "testmatrix", "deps" and "all".
+Valid options are: "none", "metacpan", "search", "rt", "anno", "ratings", "kwalitee", "testers", "testmatrix", "deps" and "all".
 
 The default is "all".
 
 	# Where the links go to:
+	metacpan	- https://metacpan.org/release/$dist
 	search		- http://search.cpan.org/dist/$dist
-	rt		- http://rt.cpan.org/NoAuth/Bugs.html?Dist=$dist
+	rt		- https://rt.cpan.org/Public/Dist/Display.html?Name=$dist
 	anno		- http://annocpan.org/dist/$dist
 	ratings		- http://cpanratings.perl.org/d/$dist
-	forum		- http://cpanforum.com/dist/$dist
-	kwalitee	- http://cpants.perl.org/dist/overview/$dist
+	kwalitee	- http://cpants.perl.org/dist/$dist
 	testers		- http://cpantesters.org/distro/$first_char/$dist
 	testmatrix	- http://matrix.cpantesters.org/?dist=$dist
 	deps		- http://deps.cpantesters.org/?module=$module
@@ -724,7 +727,7 @@ The default is "all".
 	# in weaver.ini
 	[Support]
 	websites = search
-	websites = forum
+	websites = metacpan
 	websites = testers , testmatrix
 
 P.S. If you know other websites that I should include here, please let me know!
@@ -740,7 +743,10 @@ The default is a sufficient explanation (see L</SUPPORT>).
 Specify an IRC server/channel/nick for online support. You can specify as many networks/channels as you want.
 The ordering of the options are important, as they are reflected in the final POD.
 
-You specify a network, then a list of channels/nicks to ask for support.
+You specify a network, then a list of channels/nicks to ask for support. There are two ways to format the string:
+
+	servername.com,#room,nick
+	irc://servername.com/#room
 
 The default is none.
 
@@ -749,6 +755,13 @@ The default is none.
 	irc = irc.home.org, #support, supportbot
 	irc = irc.acme.com, #acmecorp, #acmehelp, #acmenewbies
 
+You can also add the irc information in the distribution metadata via L<Dist::Zilla::Plugin::Metadata>.
+The key is 'x_IRC' but you have to use the irc:// format to retain compatibility with the rest of the ecosystem.
+
+	# in dist.ini
+	[Metadata]
+	x_IRC = irc://irc.perl.org/#perl
+
 =head2 irc_content
 
 Specify the content to be displayed before the irc network/channel list.
@@ -793,6 +806,36 @@ Please put the "{EMAIL}" placeholder somewhere!
 
 The default is a sufficient explanation ( see L</SUPPORT>).
 
+=head1 VERSION
+
+version 1.009
+
+=for stopwords dist dzil repo
+
+=for Pod::Coverage weave_section mvp_multivalue_args
+
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Apocalyptic.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/pod-weaver-section-support/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
 =head1 SUPPORT
 
 =head2 Perldoc
@@ -810,6 +853,14 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Pod-Weaver-Section-Support>
+
+=item *
+
 Search CPAN
 
 The default CPAN search engine, useful to view POD in HTML format.
@@ -822,13 +873,13 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Pod-Weaver-Section-Support>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Section-Support>
 
 =item *
 
 AnnoCPAN
 
-The AnnoCPAN is a website that allows community annonations of Perl module documentation.
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
 
 L<http://annocpan.org/dist/Pod-Weaver-Section-Support>
 
@@ -842,25 +893,17 @@ L<http://cpanratings.perl.org/d/Pod-Weaver-Section-Support>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Pod-Weaver-Section-Support>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Pod-Weaver-Section-Support>
+L<http://cpants.cpanauthors.org/dist/Pod-Weaver-Section-Support>
 
 =item *
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/P/Pod-Weaver-Section-Support>
 
@@ -868,7 +911,7 @@ L<http://www.cpantesters.org/distro/P/Pod-Weaver-Section-Support>
 
 CPAN Testers Matrix
 
-The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
 
 L<http://matrix.cpantesters.org/?dist=Pod-Weaver-Section-Support>
 
@@ -882,43 +925,10 @@ L<http://deps.cpantesters.org/?module=Pod::Weaver::Section::Support>
 
 =back
 
-=head2 Email
-
-You can email the author of this module at C<APOCAL at cpan.org> asking for help with any problems you have.
-
-=head2 Internet Relay Chat
-
-You can get live help by using IRC ( Internet Relay Chat ). If you don't know what IRC is,
-please read this excellent guide: L<http://en.wikipedia.org/wiki/Internet_Relay_Chat>. Please
-be courteous and patient when talking to us, as we might be busy or sleeping! You can join
-those networks/channels and get help:
-
-=over 4
-
-=item *
-
-irc.perl.org
-
-You can connect to the server at 'irc.perl.org' and join this channel: #perl-help then talk to this person for help: Apocalypse.
-
-=item *
-
-irc.freenode.net
-
-You can connect to the server at 'irc.freenode.net' and join this channel: #perl then talk to this person for help: Apocal.
-
-=item *
-
-irc.efnet.org
-
-You can connect to the server at 'irc.efnet.org' and join this channel: #perl then talk to this person for help: Ap0cal.
-
-=back
-
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-pod-weaver-section-support at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Pod-Weaver-Section-Support>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Pod-Weaver-Section-Support>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -927,45 +937,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://github.com/apocalypse/perl-pod-weaver-section-support>
+L<https://github.com/shlomif/perl-pod-weaver-section-support>
 
-  git clone git://github.com/apocalypse/perl-pod-weaver-section-support.git
-
-=head1 AUTHOR
-
-Apocalypse <APOCAL@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by Apocalypse.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-The full text of the license can be found in the LICENSE file included with this distribution.
-
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
-WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
-PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
-EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
-IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
-SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
-THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
-TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
-SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
-DAMAGES.
+  git clone https://github.com/shlomif/perl-pod-weaver-section-support
 
 =cut
-
